"""Top-level package for Math Base."""

__author__ = """Oh June"""
__email__ = 'tic.for.tac@gmail.com'
__version__ = '0.1.0'


from .math_base import factorial, permutation, combination
